pub struct WebSocketConnector { /* private fields */ }Expand description
A connector for establishing WebSocket connections to the Bybit WebSocket API.
Implementations
Sourceimpl WebSocketConnector
This struct provides methods to create a new connector and connect to the WebSocket server.
impl WebSocketConnector
This struct provides methods to create a new connector and connect to the WebSocket server.
Examples
use bothan_bybit::WebSocketConnector;
let connector = WebSocketConnector::new("wss://example.com/socket");
let connection = connector.connect();Sourcepub fn new(url: impl Into<String>) -> Self
pub fn new(url: impl Into<String>) -> Self
Creates a new BybitWebSocketConnector with the given URL.
Sourcepub async fn connect(&self) -> Result<WebSocketConnection, Error>
pub async fn connect(&self) -> Result<WebSocketConnection, Error>
Establishes a WebSocket connection to the Bybit server.
Errors
Returns a tungstenite::Error if the WebSocket connection fails.